clear 
set more off
capture log close

global voting "C:/Users/wb478787/Dropbox/MORE - DEC/MORE_temp/Temporary Esha/Voting_Lasso/Final Tables_Data_Code/Tables/Feb23/Data"
log using "$voting/Table_5_OA12.log", replace

**Generates Table 5 and Table OA12

use "$voting/Female_Voting_Lasso.dta", clear

gen treatxt_200 = treat_200*t
gen treatxt_200_400 = treat_200_400*t
gen treatxt_400_600 = treat_400_600*t
gen treatxt_600_800 = treat_600_800*t
gen treatxt_800_1000 = treat_800_1000*t
gen treatxt_1000_1200 = treat_1000_1200*t

bys neighborhood_code: gen tot_sample_women = _N
egen tot_treat_women = total(t==1), by(neighborhood_code) 
gen treat_sample_ratio = tot_treat_women/tot_sample_women

***Column 1 of Table 5*** 

local vars1 "treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200 treat_sample_ratio"
estpost tabstat `vars1' ,  ///
statistics (count mean sd p10 median p90 ) columns(statistics)
esttab  using "$voting/Table5_mean.csv",   cells("count mean(fmt(2)) sd(fmt(2)) p10(fmt(2)) p50(fmt(2)) p90(fmt(2))") replace nonum noobs 

drop treatxt_200-treatxt_1000_1200

*Final Lasso Controls
local controls1 "NAregist_vot_F hhsize age nc05 nall tv_access mobil_ins_allow advice_pir"

su `controls1'

gen d_hhsize=0
replace d_hhsize=1 if hhsize==.
replace hhsize=0 if hhsize==.

merge m:1 neighborhood_code using "$voting/Prob_weights_bound_cluster.dta", keepusing(actual_prob weight_t1 bound_1)
ren actual_prob prob_t1
drop _m

***Table 5***

**WLS with covariates**

xi:reg v_noinknovote t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio ///
	`controls1'  d_hhsize d_age d_num_child0to5  i.village_code  [iweight=weight_t1]  , cl(neighborhood_code)
estadd ysumm
outreg2 t sum_* treat_* treatxt_* using "$voting/Table_5.xls", replace dec(3) addstat ("Mean Dep Var", e(ymean)) ///
	keep(t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio)

***TABLE OA12***

**WLS without covariates**

xi:reg v_noinknovote t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio ///
	i.village_code  [iweight=weight_t1], cl(neighborhood_code)
estadd ysumm
outreg2 t sum_* treat_* treatxt_* using "$voting/Table_OA12.xls", replace dec(3) addstat ("Mean Dep Var", e(ymean)) ///
	keep(t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio)


**OLS with probability of being assigned to treatment 1 as an additional covariate**

xi:reg v_noinknovote t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio ///
	`controls1'  d_hhsize d_age d_num_child0to5 prob_t1 i.village_code  , cl(neighborhood_code)
estadd ysumm
outreg2 t sum_* treat_* treatxt_* using "$voting/Table_OA12.xls", append dec(3) addstat ("Mean Dep Var", e(ymean)) ///
	keep(t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio)


**OLS excluding Boundary Clusters**

xi:reg v_noinknovote t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio ///
	`controls1'  d_hhsize d_age d_num_child0to5 i.village_code if bound_1==0, cl(neighborhood_code)
estadd ysumm
outreg2 t sum_* treat_* treatxt_* using "$voting/Table_OA12.xls", append dec(3) addstat ("Mean Dep Var", e(ymean)) ///
	keep(t treat_200 treat_200_400 treat_400_600 treat_600_800 treat_800_1000 treat_1000_1200 ///
	sum_200 sum_200_400 sum_400_600 sum_600_800 sum_800_1000 sum_1000_1200  treat_sample_ratio)

