clear 
set more off
capture log close

global voting "C:/Users/wb478787/Dropbox/MORE - DEC/MORE_temp/Temporary Esha/Voting_Lasso/Final Tables_Data_Code/Tables/Feb23/Data"
log using "$voting/Table_7_OA13_OA17.log", replace

*Generates Table 7, OA13, and OA17

use "$voting/Female_Voting_Lasso.dta", clear

merge m:1 neighborhood_code using "$voting/Prob_weights_bound_cluster.dta", keepusing(actual_prob weight_t1 bound_1)
ren actual_prob prob_t1
drop _m

capture erase "$voting/Table_7.xls"
capture erase "$voting/Table_7.txt"

capture erase "$voting/Table_OA13.xls"
capture erase "$voting/Table_OA13.txt"

gen d_hhsize=0
replace d_hhsize=1 if hhsize==.
replace hhsize=0 if hhsize==.

*Lasso Controls
local controls1 "NAregist_vot_F hhsize age nc05 nall tv_access mobil_ins_allow advice_pir"

forvalues x=1/2 {
ren t`x'_m tm`x'
ren t`x'_nocc t_nocc`x'
}

foreach x in  t_nocc cc { 

**TABLE 7**

**WLS with Covariates**
xi:reg vote_PPPP_F `x'1 `x'2 `controls1'  d_hhsize d_age d_num_child0to5 i.village_code  if vote_survey==1 & v_noinknovote==1 [iweight=weight_t1], cl(neighborhood_code)
sum vote_PPPP_F if e(sample)==1 & t_m==0
local ymean=r(mean)
test `x'1=`x'2
local test1=r(p)
test `x'1 `x'2
local test2=r(p)
outreg2 `x'1 `x'2 using "$voting/Table_7.xls", nocons append bracket dec(3) addstat ("Mean Dep Var", `ymean', "test1", `test1', "test2", `test2') ///
		keep(`x'1 `x'2)

**TABLE OA13**

**WLS without covariates**
xi:reg vote_PPPP_F `x'1 `x'2 i.village_code  if vote_survey==1 & v_noinknovote==1 [iweight=weight_t1], cl(neighborhood_code)
sum vote_PPPP_F if e(sample)==1 & t_m==0
local ymean=r(mean)
test `x'1=`x'2
local test1=r(p)
test `x'1 `x'2
local test2=r(p)
outreg2 `x'1 `x'2 using "$voting/Table_OA13.xls", nocons append bracket dec(3) addstat ("Mean Dep Var", `ymean', "test1", `test1', "test2", `test2') ///
		keep(`x'1 `x'2)

**OLS including the probability of being assigned to T1 as a covariate**
xi:reg vote_PPPP_F `x'1 `x'2 `controls1'  d_hhsize d_age d_num_child0to5 prob_t1 i.village_code  if vote_survey==1 & v_noinknovote==1, cl(neighborhood_code)
sum vote_PPPP_F if e(sample)==1 & t_m==0
local ymean=r(mean)
test `x'1=`x'2
local test1=r(p)
test `x'1 `x'2
local test2=r(p)
outreg2 `x'1 `x'2 using "$voting/Table_OA13.xls", nocons append bracket dec(3) addstat ("Mean Dep Var", `ymean', "test1", `test1', "test2", `test2') ///
		keep(`x'1 `x'2)

**OLS excluding boundary clusters**
xi:reg vote_PPPP_F `x'1 `x'2 `controls1'  d_hhsize d_age d_num_child0to5 i.village_code if vote_survey==1 & v_noinknovote==1 & bound_1==0, cl(neighborhood_code)
sum vote_PPPP_F if e(sample)==1 & t_m==0
local ymean=r(mean)
test `x'1=`x'2
local test1=r(p)
test `x'1 `x'2
local test2=r(p)
outreg2 `x'1 `x'2 using "$voting/Table_OA13.xls", nocons append bracket dec(3) addstat ("Mean Dep Var", `ymean', "test1", `test1', "test2", `test2') ///
		keep(`x'1 `x'2)
}

***TABLE OA17***

**Pooled Regressions**

**targeted t1 and t2

gen tag_t1 =1 if t1 ==1 
replace tag_t1 =0 if tag_t1 ==.

gen tag_t2 = 1 if t2==1
replace tag_t2 = 0 if tag_t2 ==.

**untargeted t1 and t2
gen untag_t1 = 1 if t1==0 & tm1==1
replace untag_t1 = 0 if untag_t1 ==.

gen untag_t2 = 1 if t2==0 & tm2==1
replace untag_t2 = 0 if untag_t2 ==.

local controls1 "NAregist_vot_F hhsize age nc05 nall tv_access mobil_ins_allow advice_pir"

xi:reg vote_PPPP_F tag_t1 tag_t2 untag_t1 untag_t2 `controls1'  d_hhsize d_age d_num_child0to5 i.village_code if vote_survey==1 & v_noinknovote==1 [iweight=weight_t1], cl(neighborhood_code)
test tag_t1=untag_t1
local test1=r(p)
test tag_t1=untag_t2
local test2=r(p)
outreg2 using "$voting/Table_OA17.xls", replace bracket dec(3) addstat ("test_t1", `test1', "test_t2", `test2') keep(tag_t1 tag_t2 untag_t1 untag_t2)

log close
